==> geopsypack-src-3.4.1.tar.gz: geopsypack-src-3.4.1/SciFigs/src/NameLine.cpp <==
/***************************************************************************
**
**  This file is part of SciFigs.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2004-10-07
**  Copyright: 2004-2019
**    Marc Wathelet
**    Marc Wathelet (ULg, Liège, Belgium)
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#include "NameLine.h"
#include "LineFactory.h"

namespace SciFigs {

/*!
  \class NameLine NameLine.h
  Line with points and names stored in a Curve<NamedPoint>
*/

const QString NameLine::xmlNameLineTag="NameLine";

REGISTER_LINE(NameLine, "NameLine" );
// Compatibility
SYNONYM_LINE(DynNameLine, "NameLine" );

AbstractLine * NameLine::clone() const
{
  NameLine * l=new NameLine;
  *l=*this;
  return l;
}

void NameLine::operator=(const NameLine& o)
{
  _curve=o._curve;
  AbstractNameLine::operator=(o);
}

} // namespace SciFigs

==> geopsypack-src-3.5.1.tar.gz: geopsypack-src-3.5.1/SciFigs/src/NameLine.cpp <==
/***************************************************************************
**
**  This file is part of SciFigs.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2004-10-07
**  Copyright: 2004-2019
**    Marc Wathelet
**    Marc Wathelet (ULg, Liège, Belgium)
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#include "NameLine.h"
#include "LineFactory.h"

namespace SciFigs {

/*!
    \class NameLine NameLine.h
    Line with points and names stored in a Curve<NamedPoint>
  */

  const QString NameLine::xmlNameLineTag="NameLine";

  REGISTER_LINE(NameLine, "NameLine")
  // Compatibility
  SYNONYM_LINE(DynNameLine, "NameLine")

  NameLine::NameLine(const NameLine& o)
    : AbstractNameLine(o)
  {
    TRACE;
    _curve=o._curve;
  }

  AbstractLine * NameLine::clone() const
  {
    TRACE;
    return new NameLine(*this);
  }

  bool NameLine::canCopy(const AbstractLine& o) const
  {
    TRACE;
    return dynamic_cast<const NameLine *>(&o);
  }

  void NameLine::operator=(const AbstractLine& o)
  {
    TRACE;
    const NameLine * co=static_cast<const NameLine *>(&o);
    ASSERT(co);
    _curve=co->_curve;
    AbstractNameLine::operator=(o);
  }

} // namespace SciFigs
